# barcode
__PATTERN_DICT__ = {
                    'scopeV2.0.0': 'C8L16C8L16C8U8T18',
                    'scopeV2.0.1': 'C8L16C8L16C8L1U8T18',
                    'scopeV2.1.0': 'C8L16C8L16C8U12T18',
                    'scopeV2.1.1': 'C8L16C8L16C8L1U12T18',
                    'scopeV2.2.1': 'C8L16C8L16C8L1U12T18',
                    'scopeV3.0.1': 'C9L16C9L16C9L1U12T18',
                    'customized': None,
                    'auto': None,
                    'scopeV1': 'C12U8T18'
                    }


# count
MATRIX_FILE_NAME = 'matrix.mtx'
FEATURE_FILE_NAME = 'genes.tsv'
BARCODE_FILE_NAME = 'barcodes.tsv'

# mkref
GENOME_CONFIG = 'celescope_genome.config'
