<script> {% include "./js/jquery.dataTables.min.js" %} </script>
<script> {% include "./js/dataTables.jqueryui.min.js" %} </script>

<script> {% include "./js/jszip.min.js" %} </script>
<script> {% include "./js/dataTables.buttons.min.js" %} </script>
<script> {% include "./js/buttons.flash.min.js" %} </script>
<script> {% include "./js/buttons.html5.min.js" %} </script>
<script> {% include "./js/buttons.print.min.js" %} </script>

<style> {% include "./css/jquery-ui.css" %}</style>
<style> {% include "./css/dataTables.jqueryui.min.css" %}</style>
<style> {% include "./css/buttons.dataTables.min.css" %}</style>

<script>
    $(document).ready(function () {
            var table = $('#variant_table').DataTable({
                "scrollX": true,
                dom: 'Bfrtip',
                buttons: ['excel']
            });
            table.draw();
    });
</script>

<div class="abc" style="float: left; margin-left: 15%; margin-right:15%; width: 70%" >
    <h2>Analysis   <i class="icon-help-circled" onClick="toggle1(this)" style="cursor:pointer;"></i></h2>
    <div class="box">
        <div class="description" style="display: none;">
            <p><b>Variants Table</b></p>
            <p> VID : variant ID.</p>
            <p> Chrom : chromosome name.</p>
            <p> Pos : the 1-based position of the variation on the given sequence..</p>
            <p> Alleles : REF(reference base or bases in the case of an indel) - ALT(alternative alleles).</p>
            <p> 0/0, 0/1, 1/1: number of cells with each genotype.</p>
            <p> Gene : gene symbol.</p>
            <p> mRNA :  A standard nomenclature is used in specifying the sequence changes.</p>
            <p> Protein :  A standard nomenclature is used in specifying the sequence changes.</p>
            <p> COSMIC : COSMIC annotation.</p>
        </div>

        <h3>{{table_dict['title'] | safe}}</h3>
        <div style=" margin-left: 3%; margin-right:3%;">
            {{table_dict['table'] | safe}}
        </div>

      <div class="clear" ></div>
    </div>
  </div>